@@ -2,7 +2,6 @@ package app
 
 import (
 	"fmt"
-	"strconv"
 
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/environment"
@@ -75,9 +74,6 @@ func (c colimaApp) Start(conf config.Config) error {
 	if err := c.setRuntime(conf.Runtime); err != nil {
 		return fmt.Errorf("error setting current runtime: %w", err)
 	}
-	if err := c.setSSHPort(conf.VM.SSHPort); err != nil {
-		return fmt.Errorf("error setting SSH port: %w", err)
-	}
 	// persist kubernetes version for future reference.
 	if err := c.setKubernetesVersion(conf.Kubernetes.Version); err != nil {
 		return fmt.Errorf("error setting kubernetes version: %w", err)
@@ -252,10 +248,6 @@ func (c colimaApp) setKubernetesVersion(version string) error {
 	return c.guest.Set(environment.KubernetesVersionKey, version)
 }
 
-func (c colimaApp) setSSHPort(sshPort int) error {
-	return c.guest.Set(environment.SSHPortKey, strconv.Itoa(sshPort))
-}
-
 func (c colimaApp) currentContainerEnvironments() ([]environment.Container, error) {
 	var containers []environment.Container
 
