@@ -13,7 +13,7 @@ var deleteCmdArgs struct {
 
 // deleteCmd represents the delete command
 var deleteCmd = &cobra.Command{
-	Use:   "delete",
+	Use:   "delete [profile]",
 	Short: "delete and teardown Colima",
 	Long: `Delete and teardown Colima and all settings.
 
@@ -21,6 +21,7 @@ Use with caution. This deletes everything and a startup afterwards is like the
 initial startup of Colima.
 
 If you simply want to reset the Kubernetes cluster, run 'colima kubernetes reset'.`,
+	Args: cobra.MaximumNArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
 		if !deleteCmdArgs.force {
 			y := cli.Prompt("are you sure you want to delete " + config.Profile().DisplayName + " and all settings")
