@@ -17,20 +17,25 @@ func newConf(conf config.Config) (l Config, err error) {
 	l.Arch = environment.Arch(conf.VM.Arch).Value()
 
 	l.Images = append(l.Images,
-		File{Arch: environment.AARCH64, Location: "https://github.com/abiosoft/alpine-lima/releases/download/colima-v0.3.2/alpine-lima-clm-3.14.3-aarch64.iso", Digest: "sha512:1f93efbfb3093203446f605647438d04d239d3ee591c06b85e79f067180eff5d6b24b9133d147731a0a68d6d3b8d233eed844c99453e2f697e8df70f5b9cb1eb"},
-		File{Arch: environment.X8664, Location: "https://github.com/abiosoft/alpine-lima/releases/download/colima-v0.3.2/alpine-lima-clm-3.14.3-x86_64.iso", Digest: "sha512:875482176ff2f43bf9472f84137d8b9a56d692ae19243436079c7f2f78cb6b13576601eef9102aaea796629215fc60308e69b590c81fe4139e9e84f1ec4a57f5"},
+		File{Arch: environment.AARCH64, Location: "https://github.com/abiosoft/alpine-lima/releases/download/colima-v0.3.4-1/alpine-lima-clm-3.14.3-aarch64.iso", Digest: "sha512:363baa91e4087dfd04ec5eebadcb29b9aef45c2663642f951105b3989e93143ce45f94ba9101c01c5db46c3fc6b601340b39baad29b1a48bb4f735790048daaa"},
+		File{Arch: environment.X8664, Location: "https://github.com/abiosoft/alpine-lima/releases/download/colima-v0.3.4-1/alpine-lima-clm-3.14.3-x86_64.iso", Digest: "sha512:cd7ad0ef76088ea3d9f428e70fcddcbbcc72999568aaee0de953052299a01df251454fa5db3a0fdcfa70896bd152bc5d92f9ad81d682f3ec44cfbd2149ae3856"},
 	)
 
 	l.CPUs = conf.VM.CPU
 	l.Memory = fmt.Sprintf("%dGiB", conf.VM.Memory)
 	l.Disk = fmt.Sprintf("%dGiB", conf.VM.Disk)
 
-	l.SSH = SSH{LocalPort: conf.VM.SSHPort, LoadDotSSHPubKeys: false, ForwardAgent: conf.VM.ForwardAgent}
+	l.SSH = SSH{LocalPort: 0, LoadDotSSHPubKeys: false, ForwardAgent: conf.VM.ForwardAgent}
 	l.Containerd = Containerd{System: false, User: false}
 	l.Firmware.LegacyBIOS = false
 
 	l.DNS = conf.VM.DNS
-	l.UseHostResolver = len(l.DNS) == 0 // use host resolver when no DNS is set
+	// always use host resolver to generate Lima's default resolv.conf file
+	// colima will override this in VM when custom DNS is set
+	l.HostResolver.Enabled = true
+	l.HostResolver.Hosts = map[string]string{
+		"host.docker.internal": "host.lima.internal",
+	}
 
 	l.Env = map[string]string{}
 	for k, v := range conf.VM.Env {
@@ -50,11 +55,23 @@ func newConf(conf config.Config) (l Config, err error) {
 		}
 
 		// handle port forwarding to allow listening on 0.0.0.0
+		// bind 0.0.0.0
+		l.PortForwards = append(l.PortForwards,
+			PortForward{
+				GuestIPMustBeZero: true,
+				GuestIP:           net.ParseIP("0.0.0.0"),
+				GuestPortRange:    [2]int{1, 65535},
+				HostIP:            net.ParseIP("0.0.0.0"),
+				HostPortRange:     [2]int{1, 65535},
+				Proto:             TCP,
+			},
+		)
+		// bind 127.0.0.1
 		l.PortForwards = append(l.PortForwards,
 			PortForward{
 				GuestIP:        net.ParseIP("127.0.0.1"),
 				GuestPortRange: [2]int{1, 65535},
-				HostIP:         conf.PortInterface,
+				HostIP:         net.ParseIP("127.0.0.1"),
 				HostPortRange:  [2]int{1, 65535},
 				Proto:          TCP,
 			},
@@ -98,19 +115,19 @@ func newConf(conf config.Config) (l Config, err error) {
 
 // Config is lima config. Code copied from lima and modified.
 type Config struct {
-	Arch            environment.Arch  `yaml:"arch,omitempty"`
-	Images          []File            `yaml:"images"`
-	CPUs            int               `yaml:"cpus,omitempty"`
-	Memory          string            `yaml:"memory,omitempty"`
-	Disk            string            `yaml:"disk,omitempty"`
-	Mounts          []Mount           `yaml:"mounts,omitempty"`
-	SSH             SSH               `yaml:"ssh,omitempty"`
-	Containerd      Containerd        `yaml:"containerd"`
-	Env             map[string]string `yaml:"env,omitempty"`
-	DNS             []net.IP          `yaml:"-"` // will be handled manually by colima
-	Firmware        Firmware          `yaml:"firmware"`
-	UseHostResolver bool              `yaml:"useHostResolver"`
-	PortForwards    []PortForward     `yaml:"portForwards,omitempty"`
+	Arch         environment.Arch  `yaml:"arch,omitempty"`
+	Images       []File            `yaml:"images"`
+	CPUs         int               `yaml:"cpus,omitempty"`
+	Memory       string            `yaml:"memory,omitempty"`
+	Disk         string            `yaml:"disk,omitempty"`
+	Mounts       []Mount           `yaml:"mounts,omitempty"`
+	SSH          SSH               `yaml:"ssh"`
+	Containerd   Containerd        `yaml:"containerd"`
+	Env          map[string]string `yaml:"env,omitempty"`
+	DNS          []net.IP          `yaml:"-"` // will be handled manually by colima
+	Firmware     Firmware          `yaml:"firmware"`
+	HostResolver HostResolver      `yaml:"hostResolver"`
+	PortForwards []PortForward     `yaml:"portForwards,omitempty"`
 }
 
 type File struct {
@@ -125,11 +142,11 @@ type Mount struct {
 }
 
 type SSH struct {
-	LocalPort int `yaml:"localPort,omitempty"` // REQUIRED
+	LocalPort int `yaml:"localPort"`
 	// LoadDotSSHPubKeys loads ~/.ssh/*.pub in addition to $LIMA_HOME/_config/user.pub .
 	// Default: true
 	LoadDotSSHPubKeys bool `yaml:"loadDotSSHPubKeys"`
-	ForwardAgent      bool `yaml:"forwardAgent,omitempty"` // default: false
+	ForwardAgent      bool `yaml:"forwardAgent"` // default: false
 }
 
 type Containerd struct {
@@ -150,17 +167,25 @@ const (
 )
 
 type PortForward struct {
-	GuestIP        net.IP `yaml:"guestIP,omitempty" json:"guestIP,omitempty"`
-	GuestPort      int    `yaml:"guestPort,omitempty" json:"guestPort,omitempty"`
-	GuestPortRange [2]int `yaml:"guestPortRange,omitempty" json:"guestPortRange,omitempty"`
-	GuestSocket    string `yaml:"guestSocket,omitempty" json:"guestSocket,omitempty"`
-	HostIP         net.IP `yaml:"hostIP,omitempty" json:"hostIP,omitempty"`
-	HostPort       int    `yaml:"hostPort,omitempty" json:"hostPort,omitempty"`
-	HostPortRange  [2]int `yaml:"hostPortRange,omitempty" json:"hostPortRange,omitempty"`
-	HostSocket     string `yaml:"hostSocket,omitempty" json:"hostSocket,omitempty"`
-	Proto          Proto  `yaml:"proto,omitempty" json:"proto,omitempty"`
-	Ignore         bool   `yaml:"ignore,omitempty" json:"ignore,omitempty"`
+	GuestIPMustBeZero bool   `yaml:"guestIPMustBeZero,omitempty" json:"guestIPMustBeZero,omitempty"`
+	GuestIP           net.IP `yaml:"guestIP,omitempty" json:"guestIP,omitempty"`
+	GuestPort         int    `yaml:"guestPort,omitempty" json:"guestPort,omitempty"`
+	GuestPortRange    [2]int `yaml:"guestPortRange,omitempty" json:"guestPortRange,omitempty"`
+	GuestSocket       string `yaml:"guestSocket,omitempty" json:"guestSocket,omitempty"`
+	HostIP            net.IP `yaml:"hostIP,omitempty" json:"hostIP,omitempty"`
+	HostPort          int    `yaml:"hostPort,omitempty" json:"hostPort,omitempty"`
+	HostPortRange     [2]int `yaml:"hostPortRange,omitempty" json:"hostPortRange,omitempty"`
+	HostSocket        string `yaml:"hostSocket,omitempty" json:"hostSocket,omitempty"`
+	Proto             Proto  `yaml:"proto,omitempty" json:"proto,omitempty"`
+	Ignore            bool   `yaml:"ignore,omitempty" json:"ignore,omitempty"`
 }
+
+type HostResolver struct {
+	Enabled bool              `yaml:"enabled" json:"enabled"`
+	IPv6    bool              `yaml:"ipv6,omitempty" json:"ipv6,omitempty"`
+	Hosts   map[string]string `yaml:"hosts,omitempty" json:"hosts,omitempty"`
+}
+
 type volumeMount string
 
 func (v volumeMount) Writable() bool {
